@@ -1,3 +1,3 @@
-from . import decorators
 from .about import __author__, __doc__, __email__, __license__, __version__
+from .main import Minify
 from .main import Minify as minify
